@@ -1,9 +1,9 @@
 # frozen_string_literal: true
 
-require("test_helper")
+require "test_helper"
 
 class CompileCacheJSONTest < Minitest::Test
-  include(TmpdirHelper)
+  include TmpdirHelper
 
   module FakeJson
     Fallback = Class.new(StandardError)
@@ -15,6 +15,7 @@ class CompileCacheJSONTest < Minitest::Test
   end
 
   def setup
+    skip("Unsupported platform") unless Bootsnap::CompileCache.supported?
     super
     Bootsnap::CompileCache::JSON.init!
     FakeJson.singleton_class.prepend(Bootsnap::CompileCache::JSON::Patch)
