@@ -1,11 +1,14 @@
 # frozen_string_literal: true
 
-require("test_helper")
+require "test_helper"
 
 module Bootsnap
   module LoadPathCache
-    class LoadedFeaturesIndexTest < MiniTest::Test
+    class LoadedFeaturesIndexTest < Minitest::Test
+      include LoadPathCacheHelper
+
       def setup
+        super
         @index = LoadedFeaturesIndex.new
         # not really necessary but let's just make it a clean slate
         @index.instance_variable_set(:@lfi, {})
