@@ -1,10 +1,12 @@
 # frozen_string_literal: true
 
-require("test_helper")
+require "test_helper"
 
 module Bootsnap
   module LoadPathCache
-    class PathScannerTest < MiniTest::Test
+    class PathScannerTest < Minitest::Test
+      include LoadPathCacheHelper
+
       DLEXT = RbConfig::CONFIG["DLEXT"]
       OTHER_DLEXT = DLEXT == "bundle" ? "so" : "bundle"
 
